==> fec-0.0.73.tgz: package/src/build.js <==
import { HelmetProvider, Helmet } from 'react-helmet-async'
import { JSDOM } from 'jsdom'
import { SheetsRegistry, JssProvider } from 'react-jss'
import { reduce } from 'lodash'
import { renderToString } from 'react-dom/server'
import { transformAsync } from '@babel/core'
import React from 'react'
import marked from 'marked'

import { runInNewContext } from 'vm'
import config from 'lib/config'
import fs from 'fs'

const normalizeCSS = fs.readFileSync(require.resolve('normalize.css')),
  babelConfig = Object.assign(require('../babel.config.js'), { ignore: [] })

export default async function build(node) {
  for (const key in node.children) {
    const child = node.children[key]

    if (child.isDirectory) {
      await build(child)
    } else {
      console.log(`rendering ${node.path}`)
      await render(child)
    }
  }
}

async function renderStaticHtml(jsx, node) {
  const imports = reduce(
      node.data.imports,
      (js, src, name) => {
        return js + `import ${name} from '${src}';\n`
      },
      '',
    ),
    { code: rawCode } = await transformAsync(
      `
        ${imports}

        __render_result__ = renderToString(
          <div id="page">
            <JssProvider registry={__sheets__}>
              <HelmetProvider context={__helmetContext__}>
                <Helmet>
                  <meta name="viewport" content="width=device-width, initial-scale=1"/>
                </Helmet>
                <Layout>
                  ${jsx}
                </Layout>
              </HelmetProvider>
            </JssProvider>
          </div>
        )`,
      babelConfig,
    ),
    _foo = (() => console.warn(code))(),
    _foo2 = (() => process.exit(1)),
    context = {
      require,
      config,
      pageContext: node.pageContext,
      React,
      Helmet,
      HelmetProvider,
      Layout: React.Fragment,
      JssProvider,
      renderToString,
      __sheets__: new SheetsRegistry(),
      __helmetContext__: {},
      __render_result__: null,
      window: new JSDOM().window,
      process: {
        env: {
          SSR: true,
        },
      },
    },
    code = rawCode.replace(/"use strict";/gi, ''),
    _vmResult = runInNewContext(code, context),
    html = context.__render_result__,
    css = context.__sheets__.toString(),
    { helmet } = context.__helmetContext__,
    result = `
      <!doctype html>
      <html ${helmet.htmlAttributes.toString()}>
        <head>
            ${helmet.title.toString()}
            ${helmet.meta.toString()}
            ${helmet.link.toString()}
            <style id="normalize">${normalizeCSS}</style>
            <style id="rest-button">
              button.plain {
                outline-style: none;
                padding: 0;
                border: none;
                font: inherit;
                color: inherit;
                background-color: transparent;
                cursor: pointer;
              }
            </style>
            <style id="ssr-stylesheet">${css}</style>
        </head>
        <body ${helmet.bodyAttributes.toString()}>
          ${html}
        </body>
      </html>
    `

  return result
}

async function renderWebJS(jsx, node) {
  const imports = reduce(
      { ...node.data.imports, React: 'react' },
      (js, src, name) => {
        return js + `import ${name} from '${src}';\n`
      },
      '',
    ),
    { code: js } = await transformAsync(`<>${jsx}</>`, babelConfig),
    code = `
      ${imports}
      window.Page = () => ${js.replace(/"use strict";/gi, '')};
      window.pageContext = ${JSON.stringify(node.pageContext)};
      require('lib/web-runtime');
  `

  return code
}

async function render(node) {
  const { source } = node,
    jsx = marked(source),
    js = await renderWebJS(jsx, node),
    html = await renderStaticHtml(jsx, node)

  Object.assign(node, { html, js })
}

==> fec-0.0.75.tgz: package/src/build.js <==
import { HelmetProvider, Helmet } from 'react-helmet-async'
import { JSDOM } from 'jsdom'
import { SheetsRegistry, JssProvider } from 'react-jss'
import { reduce } from 'lodash'
import { renderToString } from 'react-dom/server'
import { transformAsync } from '@babel/core'
import React from 'react'
import marked from 'marked'

import { runInNewContext } from 'vm'
import config from 'lib/config'
import fs from 'fs'

const normalizeCSS = fs.readFileSync(require.resolve('normalize.css')),
  babelConfig = Object.assign(require('../babel.config.js'), { ignore: [] })

export default async function build(node) {
  for (const key in node.children) {
    const child = node.children[key]

    if (child.isDirectory) {
      await build(child)
    } else {
      console.log(`rendering ${node.path}`)
      await render(child)
    }
  }
}

async function renderStaticHtml(jsx, node) {
  const imports = reduce(
      node.data.imports,
      (js, src, name) => {
        return js + `import ${name} from '${src}';\n`
      },
      '',
    ),
    { code: rawCode } = await transformAsync(
      `
        ${imports}

        __render_result__ = renderToString(
          <div id="page">
            <JssProvider registry={__sheets__}>
              <HelmetProvider context={__helmetContext__}>
                <Helmet>
                  <meta name="viewport" content="width=device-width, initial-scale=1"/>
                </Helmet>
                <Layout>
                  ${jsx}
                </Layout>
              </HelmetProvider>
            </JssProvider>
          </div>
        )`,
      babelConfig,
    ),
    _foo = (() => console.warn('code', rawCode))(),
    _foo2 = (() => process.exit(1)),
    context = {
      require,
      config,
      pageContext: node.pageContext,
      React,
      Helmet,
      HelmetProvider,
      Layout: React.Fragment,
      JssProvider,
      renderToString,
      __sheets__: new SheetsRegistry(),
      __helmetContext__: {},
      __render_result__: null,
      window: new JSDOM().window,
      process: {
        env: {
          SSR: true,
        },
      },
    },
    code = rawCode.replace(/"use strict";/gi, ''),
    _vmResult = runInNewContext(code, context),
    html = context.__render_result__,
    css = context.__sheets__.toString(),
    { helmet } = context.__helmetContext__,
    result = `
      <!doctype html>
      <html ${helmet.htmlAttributes.toString()}>
        <head>
            ${helmet.title.toString()}
            ${helmet.meta.toString()}
            ${helmet.link.toString()}
            <style id="normalize">${normalizeCSS}</style>
            <style id="rest-button">
              button.plain {
                outline-style: none;
                padding: 0;
                border: none;
                font: inherit;
                color: inherit;
                background-color: transparent;
                cursor: pointer;
              }
            </style>
            <style id="ssr-stylesheet">${css}</style>
        </head>
        <body ${helmet.bodyAttributes.toString()}>
          ${html}
        </body>
      </html>
    `

  return result
}

async function renderWebJS(jsx, node) {
  const imports = reduce(
      { ...node.data.imports, React: 'react' },
      (js, src, name) => {
        return js + `import ${name} from '${src}';\n`
      },
      '',
    ),
    { code: js } = await transformAsync(`<>${jsx}</>`, babelConfig),
    code = `
      ${imports}
      window.Page = () => ${js.replace(/"use strict";/gi, '')};
      window.pageContext = ${JSON.stringify(node.pageContext)};
      require('lib/web-runtime');
  `

  return code
}

async function render(node) {
  const { source } = node,
    jsx = marked(source),
    js = await renderWebJS(jsx, node),
    html = await renderStaticHtml(jsx, node)

  Object.assign(node, { html, js })
}
